@@ -206,7 +206,7 @@ int nodeVisitDebug();
 
 #define	setDevMult(i,f) { esFMult[(i)] = (float)(f); }
 
-#define	getCurDevMult() ((esFMult) ? esFMult[esFMIndex-1] : (float)1.0)
+#define	getCurDevMult() ((esFMult && (esFMIndex > 0)) ? esFMult[esFMIndex-1] : (float)1.0)
 
 /* cache list used to find parallel devs */
 typedef struct _devMerge {
@@ -1757,7 +1757,7 @@ spcdevVisit(dev, hierName, trans)
 			if (esScale < 0)
 			    fprintf(esSpiceF, "%d", dev->dev_area * scale * scale);
 			else
-			    fprintf(esSpiceF, "%gu", dev->dev_area * scale * scale
+			    fprintf(esSpiceF, "%gp", dev->dev_area * scale * scale
 					* esScale * esScale * sdM);
 			break;
 		    case 'p':
